@@ -35,6 +35,9 @@ sub build_binaries {
 
   #make options
   my @makeopts   = qw[USE_NODEPEND=Yes];
+  
+  #extra options for iup/imglib
+  push(@makeopts, 'USE_IUP_IMGLIB_LARGE=1') if $self->notes('build_large_imglib');
 
   #store debug info into ConfigData
   $self->config_data('info_imtargets', \@imtargets);
