@@ -22,7 +22,7 @@ sub build_binaries {
   
   if ($self->notes('is_devel_cvs_version')) {
     ### DEVEL BUILD ###
-    @imtargets  = qw[im im_process im_jp2 im_fftw im_capture];
+    @imtargets  = qw[im im_process im_jp2 im_fftw]; #xxx im_capture removed
     @cdtargets  = qw[cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
     @iuptargets = qw[iup iupcd iupcontrols iup_pplot iupgl iupim iupimglib iupole iupweb iuptuio];
   }
@@ -30,11 +30,11 @@ sub build_binaries {
     @imtargets  = qw[im];
     @cdtargets  = qw[cd_freetype cd];
     @iuptargets = qw[iup iupcd iupcontrols iup_pplot iupgl iupim iupimglib iupole];
-    if ($Config{cc} =~ /cl/ && $Config{ccversion} =~ /^12\./) {
-      warn "###WARN### skipping cd_ftgl+iuptuio on VC6";
-      @cdtargets  = grep { $_ !~ /^(cd_ftgl)$/ } @cdtargets;     # disable just when compiling via VC6
-      @iuptargets = grep { $_ !~ /^(iuptuio)$/ } @iuptargets;    # disable just when compiling via VC6
-    }
+    #if ($Config{cc} =~ /cl/ && $Config{ccversion} =~ /^12\./) {
+    #  warn "###WARN### skipping cd_ftgl+iuptuio on VC6";
+    #  @cdtargets  = grep { $_ !~ /^(cd_ftgl)$/ } @cdtargets;     # disable just when compiling via VC6
+    #  @iuptargets = grep { $_ !~ /^(iuptuio)$/ } @iuptargets;    # disable just when compiling via VC6
+    #}
   }
   
   #xxx TODO add cdcontextplus + iupweb support to makefiles
@@ -56,7 +56,7 @@ sub build_binaries {
       push(@cmd_im,  'CFG=Win64');
       push(@cmd_cd,  'CFG=Win64');
       push(@cmd_iup, 'CFG=Win64');
-    }
+    }    
   }
   else { # gcc compiler
     my $make = $self->notes('gnu_make') || $self->get_make;
@@ -71,8 +71,11 @@ sub build_binaries {
       push(@cmd_im,  'BUILDBITS=64');
       push(@cmd_cd,  'BUILDBITS=64');
       push(@cmd_iup, 'BUILDBITS=64');
-    }
+    }    
   }
+  
+  #common for both compilers
+  push(@cmd_iup, 'CF_iupimglib_EXTRA=-DIUP_IMGLIB_LARGE') if $self->notes('build_large_imglib');
 
   my $libtype = 'static';
   my $success = 1;
